from django.urls import reverse

import django_tables2 as tables
from django_tables2.utils import A

from benevalibre.utils.tables import ActionsColumn

from . import models


class AssociationRelativeActionsMixin:
    actions_update_url = None
    actions_delete_url = None

    def __init__(self, *args, **kwargs):
        extra_columns = kwargs.pop('extra_columns', [])
        extra_columns.append(
            (
                'actions',
                ActionsColumn(
                    update_url=self.get_actions_update_url,
                    delete_url=self.get_actions_delete_url,
                ),
            )
        )
        super().__init__(*args, extra_columns=extra_columns, **kwargs)

    def get_actions_update_url(self, record):
        if self.actions_update_url:
            return reverse(
                self.actions_update_url,
                args=(record.association.pk, record.pk),
            )
        return None

    def get_actions_delete_url(self, record):
        if self.actions_delete_url:
            return reverse(
                self.actions_delete_url,
                args=(record.association.pk, record.pk),
            )
        return None


class ProjectIndexTable(AssociationRelativeActionsMixin, tables.Table):
    actions_update_url = 'association:project:update'
    actions_delete_url = 'association:project:delete'

    name = tables.LinkColumn(
        'association:project:update', args=(A('association.id'), A('pk'))
    )

    class Meta:
        model = models.Project
        fields = ('name', 'actions')


class RoleIndexTable(AssociationRelativeActionsMixin, tables.Table):
    actions_update_url = 'association:role:update'
    actions_delete_url = 'association:role:delete'

    name = tables.LinkColumn(
        'association:role:update', args=(A('association.id'), A('pk'))
    )

    class Meta:
        model = models.Role
        fields = ('name', 'actions')


class LevelIndexTable(AssociationRelativeActionsMixin, tables.Table):
    actions_update_url = 'association:level:update'
    actions_delete_url = 'association:level:delete'

    name = tables.LinkColumn(
        'association:level:update', args=(A('association.id'), A('pk'))
    )

    class Meta:
        model = models.Level
        fields = ('name', 'actions')


class CategoryIndexTable(AssociationRelativeActionsMixin, tables.Table):
    actions_update_url = 'association:category:update'
    actions_delete_url = 'association:category:delete'

    name = tables.LinkColumn(
        'association:category:update', args=(A('association.id'), A('pk'))
    )

    class Meta:
        model = models.Category
        fields = ('name', 'instance_category', 'actions')
