import datetime

from django import forms

import pytest

from ..forms import CustomTapeformMixin


class DummyForm(CustomTapeformMixin, forms.Form):
    my_field1 = forms.CharField()
    my_field2 = forms.BooleanField()
    my_field3 = forms.ChoiceField(choices=(('foo', 'foo'), ('bar', 'bar')))
    my_field4 = forms.FileField()
    my_field5 = forms.DateField()


@pytest.fixture
def form():
    return DummyForm()


class TestCustomTapeformMixin:
    def test_base_layout_template(self, form):
        assert form.base_layout_template == 'tapeforms/layouts/bootstrap.html'

    def test_date_input_format(self, form):
        widget = form.fields['my_field5'].widget
        assert widget.format == '%Y-%m-%d'
        assert widget.format_value(datetime.date(2019, 1, 1)) == '2019-01-01'

    def test_css_class_default(self, form):
        assert (
            form.get_field_container_css_class(form['my_field1'])
            == 'form-group'
        )
        assert form.get_field_label_css_class(form['my_field1']) is None
        assert (
            form.get_widget_css_class('my_field1', form.fields['my_field1'])
            == 'form-control'
        )

    def test_css_class_checkbox(self, form):
        assert (
            form.get_field_container_css_class(form['my_field2'])
            == 'form-group custom-control custom-checkbox'
        )
        assert (
            form.get_field_label_css_class(form['my_field2'])
            == 'custom-control-label'
        )
        assert (
            form.get_widget_css_class('my_field2', form.fields['my_field2'])
            == 'custom-control-input'
        )

    def test_css_class_select(self, form):
        assert (
            form.get_widget_css_class('my_field3', form.fields['my_field3'])
            == 'custom-select'
        )

    def test_css_class_file(self, form):
        assert (
            form.get_widget_css_class('my_field4', form.fields['my_field4'])
            == 'custom-file-input'
        )
